@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
 use lib '../lib';
-use File::MimeInfo::Simple;
+use File::MimeInfo::Simple '0.3';
 
 print mimetype($ARGV[0]), "\n";
\ No newline at end of file
